@@ -1,3 +1,5 @@
+#!/usr/bin/env python3
+
 """ahp_graph architecture describing PingPong."""
 
 from ahp_graph.Device import *
@@ -7,7 +9,7 @@ from ahp_graph.DeviceGraph import *
 class Ping(Device):
     """Ping Device: has a Name and a Model type."""
 
-    library = 'pingpong.Ping'
+    library = 'pingpong.Ping' # this is set in the respective .h file using SST_ELI_REGISTER_COMPONENT
     portinfo = PortInfo()
     portinfo.add('input', 'String')
     portinfo.add('output', 'String')
@@ -16,7 +18,7 @@ class Ping(Device):
 class Pong(Device):
     """Pong Device."""
 
-    library = 'pingpong.Pong'
+    library = 'pingpong.Pong' # this is set in the respective .h file using SST_ELI_REGISTER_COMPONENT
     portinfo = PortInfo()
     portinfo.add('input', 'String')
     portinfo.add('output', 'String')
@@ -38,16 +40,16 @@ class pingpong(Device):
         pong = Pong('Pong')  # create a Pong Device
 
         # link ping and pong, automatically adds the devices to the graph
-        graph.link(ping.output, pong.input, '1s')
+        graph.link(ping.output, pong.input, '1s')  # type: ignore[arg-type]
 
         # Generally you don't want to put latency on the links to assembly
         # ports (ex: self.port) and allow whatever uses the assembly to
         # specify latency for the connection (it will get ignored anyway)
 
         # Connect pingpong's input to ping's input
-        graph.link(ping.input, self.input)
+        graph.link(ping.input, self.input)  # type: ignore[arg-type]
         # Connect pingpong's output to pong's output
-        graph.link(pong.output, self.output)
+        graph.link(pong.output, self.output)  # type: ignore[arg-type]
 
 
 def architecture(repeats: int = 10, num: int = 1) -> DeviceGraph:
@@ -60,6 +62,6 @@ def architecture(repeats: int = 10, num: int = 1) -> DeviceGraph:
         pingpongs[i].set_partition(i)
 
     for i in range(num):
-        graph.link(pingpongs[i].output, pingpongs[(i+1) % num].input, '2s')
+        graph.link(pingpongs[i].output, pingpongs[(i+1) % num].input, '2s')  # type: ignore[arg-type]
 
     return graph
